@@ -1,6 +1,4 @@
-import json
 from typing import Any, List, Dict
-from specklepy.logging.exceptions import SpeckleException
 from specklepy.transports.abstract_transport import AbstractTransport
 
 
@@ -28,10 +26,7 @@ class MemoryTransport(AbstractTransport):
         raise NotImplementedError
 
     def get_object(self, id: str) -> str or None:
-        if id in self.objects:
-            return self.objects[id]
-        else:
-            return None
+        return self.objects[id] if id in self.objects else None
 
     def has_objects(self, id_list: List[str]) -> Dict[str, bool]:
         return {id: (id in self.objects) for id in id_list}
